package com.xy.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.xy.utils.PageBean;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

@Data
@Accessors(chain = true)
public class DeviceQualityDto {

    @Data
    @Accessors(chain = true)
    public static class Page extends Vo {

        @ApiModelProperty("分页对象")
        private PageBean page;

        @JsonFormat(pattern = "yyyy-MM-dd")
        @ApiModelProperty(value = "更新时间-起")
        private LocalDate beginUpdateTime;

        @JsonFormat(pattern = "yyyy-MM-dd")
        @ApiModelProperty(value = "更新时间-始")
        private LocalDate endUpdateTime;

        public LocalDateTime getBeginUpdateTime() {
            return beginUpdateTime == null ? null : beginUpdateTime.atTime(0, 0, 0);
        }

        public LocalDateTime getEndUpdateTime() {
            return endUpdateTime == null ? null : endUpdateTime.atTime(23, 59, 59);
        }
    }

    @Data
    @Accessors(chain = true)
    public static class Qrcode {

        @NotNull(message = "deviceId不能为空")
        @ApiModelProperty("设备ID")
        private Long deviceId;
    }

    @Data
    @Accessors(chain = true)
    public static class SelectList {

        @ApiModelProperty("唯一标识")
        private List<Integer> qualityIds;

        @ApiModelProperty("设备ID")
        private List<Long> deviceIds;
    }


    @Data
    @Accessors(chain = true)
    public static class Vo {

        @ApiModelProperty("唯一标识")
        private Integer qualityId;

        @ApiModelProperty("设备ID")
        private Long deviceId;

        @ApiModelProperty("出厂状态")
        private Integer factoryState;

        @ApiModelProperty("出厂审核人ID")
        private Long factoryAuditUserId;

        @ApiModelProperty("质量状态")
        private Integer qualityState;

        @ApiModelProperty("质检状态审核人ID")
        private Long qualityAuditUserId;

        @ApiModelProperty("设备类型")
        private Integer deviceType;

        @ApiModelProperty("交易测试状态")
        private Integer tradeState;

        @ApiModelProperty("门锁状态")
        private Integer lockerState;

        @ApiModelProperty("温度检测状态")
        private Integer tempratureState;

        @ApiModelProperty("模拟批量测试状态")
        private Integer imitateTestState;

        @ApiModelProperty("软件硬系统状态")
        private Integer systemState;

        @ApiModelProperty("参数设置状态")
        private Integer settingState;

        @ApiModelProperty("更新时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime updateTime;

        @ApiModelProperty("创建时间")
        @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
        private LocalDateTime createTime;

        @ApiModelProperty("显示状态")
        private Boolean showStatus;
    }
}
